@@ -12,23 +12,31 @@
 #
 
 Facter.add(:kernelrelease) do
-    setcode 'uname -r'
+  setcode 'uname -r'
 end
 
 Facter.add(:kernelrelease) do
-    confine :kernel => :aix
-    setcode 'oslevel -s'
+  confine :kernel => "aix"
+  setcode 'oslevel -s'
 end
 
 Facter.add(:kernelrelease) do
-    confine :kernel => %{windows}
-    setcode do
-        require 'facter/util/wmi'
-        version = ""
-        Facter::Util::WMI.execquery("SELECT Version from Win32_OperatingSystem").each do |ole|
-            version = "#{ole.Version}"
-            break
-        end
-        version
+  confine :kernel => "hp-ux"
+  setcode do
+    version = Facter::Util::Resolution.exec('uname -r') 
+    version[2..-1]
+  end
+end
+
+Facter.add(:kernelrelease) do
+  confine :kernel => "windows"
+  setcode do
+    require 'facter/util/wmi'
+    version = ""
+    Facter::Util::WMI.execquery("SELECT Version from Win32_OperatingSystem").each do |ole|
+      version = "#{ole.Version}"
+      break
     end
+    version
+  end
 end
