@@ -5,6 +5,13 @@ require 'facter/util/loader'
 # Manage which facts exist and how we access them.  Largely just a wrapper
 # around a hash of facts.
 class Facter::Util::Collection
+
+  def initialize(internal_loader, external_loader)
+    @facts = Hash.new
+    @internal_loader = internal_loader
+    @external_loader = external_loader
+  end
+
   # Return a fact object by name.  If you use this, you still have to call
   # 'value' on it to retrieve the actual value.
   def [](name)
@@ -31,7 +38,14 @@ class Facter::Util::Collection
       end
     end
 
-    if block_given? and resolve = fact.add(&block)
+    if block_given?
+      resolve = fact.add(&block)
+    else
+      resolve = fact.add
+    end
+
+    # Set any resolve-appropriate options
+    if resolve
       # If the resolve was actually added, set any resolve-appropriate options
       options.each do |opt, value|
         method = opt.to_s + "="
@@ -53,6 +67,7 @@ class Facter::Util::Collection
 
   # Iterate across all of the facts.
   def each
+    load_all
     @facts.each do |name, fact|
       value = fact.value
       unless value.nil?
@@ -66,10 +81,14 @@ class Facter::Util::Collection
     name = canonize(name)
 
     # Try to load the fact if necessary
-    loader.load(name) unless @facts[name]
+    load(name) unless @facts[name]
 
     # Try HARDER
-    loader.load_all unless @facts[name]
+    internal_loader.load_all unless @facts[name]
+
+    if @facts.empty?
+      Facter.warnonce("No facts loaded from #{internal_loader.search_path.join(File::PATH_SEPARATOR)}")
+    end
 
     @facts[name]
   end
@@ -79,26 +98,29 @@ class Facter::Util::Collection
     @facts.each { |name, fact| fact.flush }
   end
 
-  def initialize
-    @facts = Hash.new
-  end
-
   # Return a list of all of the facts.
   def list
+    load_all
     return @facts.keys
   end
 
+  def load(name)
+    internal_loader.load(name)
+    external_loader.load(self)
+  end
+
   # Load all known facts.
   def load_all
-    loader.load_all
+    internal_loader.load_all
+    external_loader.load(self)
   end
 
-  # The thing that loads facts if we don't have them.
-  def loader
-    unless defined?(@loader)
-      @loader = Facter::Util::Loader.new
-    end
-    @loader
+  def internal_loader
+    @internal_loader
+  end
+
+  def external_loader
+    @external_loader
   end
 
   # Return a hash of all of our facts.
