@@ -76,11 +76,25 @@ module Facter::Util::Virtual
      (txt =~ /QEMU Virtual CPU/) ? true : false
   end
 
+  def self.virtualbox?
+    File.read("/sys/devices/virtual/dmi/id/product_name") =~ /VirtualBox/ rescue false
+  end
+
   def self.kvm_type
     # TODO Tell the difference between kvm and qemu
     # Can't work out a way to do this at the moment that doesn't
     # require a special binary
-    "kvm"
+    if self.kvm?
+      "kvm"
+    end
+  end
+
+  def self.rhev?
+    File.read("/sys/devices/virtual/dmi/id/product_name") =~ /RHEV Hypervisor/ rescue false
+  end
+
+  def self.ovirt?
+    File.read("/sys/devices/virtual/dmi/id/product_name") =~ /oVirt Node/ rescue false
   end
 
   def self.jail?
@@ -95,7 +109,22 @@ module Facter::Util::Virtual
     Facter::Util::Resolution.exec("/usr/bin/getconf MACHINE_MODEL").chomp =~ /Virtual Machine/
   end
 
-   def self.zlinux?
+  def self.zlinux?
     "zlinux"
-   end
+  end
+
+  ##
+  # read_sysfs Reads the raw data as per the documentation at [Detecting if You
+  # Are Running in Google Compute
+  # Engine](https://developers.google.com/compute/docs/instances#dmi)  This
+  # method is intended to provide an easy seam to mock.
+  #
+  # @api public
+  #
+  # @return [String] or nil if the path does not exist
+  def self.read_sysfs_dmi_entries(path="/sys/firmware/dmi/entries/1-0/raw")
+    if File.exists?(path)
+      File.read(path)
+    end
+  end
 end
